function addFeeder(obj, fedPixels, amplitude, phase)
%% addFeeder add feeder to common edge of two pixels
%
%  INPUTS
%   fedPixels:    two number IDs of adjacent pixels, double [1 x 2]
%   amplitude:    amplitude of feeding, double [1 x 1]
%   phase:        phase of feeding in rads, double [1 x 1]
% 
%  SYNTAX
%  
%  obj.addFeederfedPixels, amplitude, phase)
%
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com

validate = @(x) isnumeric(x) && isfinite(x) && isscalar(x);
validate2 = @(x, y) ~any(all((x == y(1)) + (x == y(2)), 2));
if numel(fedPixels) == 2 && validate(amplitude) && validate(phase) && ...
        validate2(obj.FedPixels, fedPixels)
    RWGfeed = pixeling.getMapData(obj.Map, 'RWGin', ...
        fedPixels, false);
    
    RWGfeed = intersect(RWGfeed{1}, RWGfeed{2});
    if isempty(RWGfeed)
        fprintf(['AntennaBuilder: It was not possible to set feeder. ' ...
            'There is not a common edge.\n']);
        return
    end
    
    obj.FedPixels(end + 1, :) = fedPixels;
    obj.FeedingSettings(end + 1, :) = amplitude * exp(1j * phase);
    
    edgeCentroid = ...
        obj.Mesh.triangleEdgeCenters(obj.BasisFcns.data(RWGfeed, 3), :);
    edge =  obj.Mesh.edges(obj.BasisFcns.data(RWGfeed, 3), :);
    plusNode = obj.Mesh.nodes(obj.BasisFcns.data(RWGfeed, 1), :);
    
    edgeNodes = obj.Mesh.nodes(edge, :);
    edgeVector = [edgeNodes(1, 1) - edgeNodes(2, 1), ...
        edgeNodes(1, 2) - edgeNodes(2, 2)];
    if obj.GUI.Sign(plusNode(1), plusNode(2), edgeNodes(1, 1), ...
            edgeNodes(1, 2), edgeNodes(2, 1), edgeNodes(2, 2)) > 0
        arrowVector = [-edgeVector(2) edgeVector(1) 0];
    else
        arrowVector = [edgeVector(2) -edgeVector(1) 0];
    end
    
    obj.FeedingArrows(end + 1, :) = [edgeCentroid arrowVector 0];
    magnitudes = ...
        0.5 * abs(obj.FeedingSettings) / max(abs(obj.FeedingSettings));
    
    obj.FeedingArrows = [obj.FeedingArrows(:, 1:6) magnitudes];
else
    fprintf('AntennaBuilder: It was not possible to set feeder\n');
end

obj.GUI.FeedingPosition = obj.feedingPosition;
obj.GUI.update;
end

