function [feedingPosition, V] = feedingPosition(obj)
%% feedingPosition returns position of feeding and V vector
%
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com

nFeeders = size(obj.FedPixels, 1);
feedingPosition = nan(nFeeders, 6);
V = zeros(obj.BasisFcns.nUnknowns, 1);

for thisFeeder = 1: nFeeders
    Vtemp = zeros(obj.BasisFcns.nUnknowns, 1);
    RWGfeed = pixeling.getMapData(obj.Map, 'RWGin', ...
        obj.FedPixels(thisFeeder, :), false);
    
    Vtemp(intersect(RWGfeed{1}, RWGfeed{2})) = ...
        obj.FeedingSettings(thisFeeder);
    V = V + Vtemp;
    feedingTemp =  obj.Mesh.nodes( ...
        obj.Mesh.edges( ...
        obj.BasisFcns.data( ...
        Vtemp == obj.FeedingSettings(thisFeeder),3), ...
        :),:); % vertices of feeder
    if ~isempty(feedingTemp)
        feedingPosition(thisFeeder, :) = ...
            [feedingTemp(1, :) feedingTemp(2, :)];
    else
        
    end
end
end

