function removeFeeder(obj, feeder)
%% removeFeeder removes feeder
%
%  INPUTS
%   feeder:    serial number of feeder, double [1 x 1]
%              or
%              two number IDs of adjacent pixels, double [1 x 2]
%
%  SYNTAX
%  
%  obj.removeFeeder(feeder)
%  
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com

nFeeders = size(obj.FedPixels, 1);
inputSize = numel(feeder);
validate = @(x) isnumeric(x) && isfinite(x) && isscalar(x);
validate2 = @(x, y) any(all((x == y(1)) + (x == y(2)), 2));

if inputSize == 1 && validate(feeder) && nFeeders >= feeder && ...
        feeder > 0
    obj.FedPixels(feeder, :) = [];
    obj.FeedingSettings(feeder, :) = [];
    obj.FeedingArrows(feeder, :) = [];
    
elseif inputSize == 2 && validate(feeder) && ...
        validate2(obj.FedPixels, feeder)
    position = all((x == y(1)) + (x == y(2)), 2);
    obj.FedPixels(position, :) = [];
    obj.FeedingSettings(position, :) = [];
    obj.FeedingArrows(position, :) = [];
    
else
    fprintf('AntennaBuilder: It was not possible to remove feeder\n');
    return;
end

obj.GUI.FeedingPosition = obj.feedingPosition;
obj.GUI.update;
end

