function solve(obj)
%% solve core computational function
%
% Included in AToM, info@antennatoolbox.com
%  2018, Miloslav Capek, CTU in Prague, miloslav.capek@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com

pixelValuesTemp = obj.PixelValues;
pixelValuesTemp(obj.FedPixels) = -1;
RWGskip = unique(pixeling.getMapData(obj.Map, 'RWGin', ...
    (pixelValuesTemp == 0 | pixelValuesTemp == 2)));

[~, V] = obj.feedingPosition;

C = eye(obj.BasisFcns.nUnknowns);
C(:, RWGskip) = [];

C10 = @(A) C'*A;
C20 = @(A) C'*A*C;

V0    = C10(V);
Z0    = C20(obj.Operators.Z);
omXm0 = C20(obj.Operators.omXm);
omXe0 = C20(obj.Operators.omXe);

I0 = Z0 \ V0;
I  = C * I0;

af.Prad = @(I) real(I' * real(Z0) * I) / 2;
af.omWm = @(I) real(I' * omXm0*I) / 4;
af.omWe = @(I) real(I' * omXe0*I) / 4;
af.Qm   = @(I) af.omWm(I) / af.Prad(I);
af.Qe   = @(I) af.omWe(I) / af.Prad(I);
af.Qmax = @(I) 2 * max(af.Qm(I), af.Qe(I));

solution.iVec = I;
solution.Qm = af.Qm(I0);
solution.Qe = af.Qe(I0);
solution.Qmax = af.Qmax(I0);

fprintf(['AntennaBuilder results: Qm = %10.3f; Qe = %10.3f;' ...
    ' Qmax = %10.3f\n'], af.Qm(I0), af.Qe(I0), af.Qmax(I0));

obj.saveSolution(solution, 0);
end

