classdef GUI < handle
    %% GUI graphical user interface belonging to ANTENNABUILDER
    %
    % Included in AToM, info@antennatoolbox.com
    %  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com
    %  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com
    
    properties (Access = {?AntennaBuilder}, Hidden = true)
        Handles
        MainFigure
        AntennaBuilder
        NewUserFigure
        
        LastPixel
        ButtonSolveState = 'results';
        ButtonClearState = 'current';
        
        Sign
        
        Timer
        
        %% Task
        FeedingPosition
        Pixels
        Edges
    end
    
    properties
        % Graphics
        MainFont
        ButtonFontSize
        TextfieldFontSize
        TextfieldResultFontSize
        MainFontSize
        MainFontColor
        RecordColor
        LimitColor
        
        
        
        FigureBackgroundColor
        ButtonCommonProperties
        TextCommonProperties
        TextResultCommonProperties
        PanelCommonProperties
        ButtonBackgroundColor
        ResultFieldBackgroundColor
        ButtonFontColor
        HistoryLineCommonProperties
        HistoryBarCmap
        
        Cmap
        TextFontSize
        TextFontColor
        FeederColor
        FeederWidth
        
        ButtonSolveString
        ButtonClearString
    end
    
    methods (Access = {?AntennaBuilder}, Hidden = true)
        function obj = GUI(AntennaBuilder)
            obj.AntennaBuilder = AntennaBuilder;
            obj.graphicalStyle();
            obj.initialize();
            
            obj.LastPixel = [];
            obj.Sign = @(PTX, PTY, P1X, P1Y, P2X, P2Y) ...
                (PTX - P2X) .* (P1Y - P2Y) - ...
                (PTY - P2Y) .* (P1X - P2X);
            
            %%
            obj.Timer = timer;
            obj.Timer.StartFcn = @(a, b) obj.updateResults();
            obj.Timer.TimerFcn = @(a, b) '';
            
            %%
            obj.AntennaBuilder.isGUIOpened = 1;
        end
        
        %
        prepare(obj);
        % graphics
        graphicalStyle(obj);
        initialize(obj);
        reset(obj);
        update(obj);
        updatePixel(obj, selection);
        updateResults(obj);
        
        % control
        setCallbacks(obj);
        buttonClear(obj);
        buttonMouse(obj);
        buttonTablet(obj);
        buttonTeamviewer(obj);
        
        newUser(obj);
        updateUser(obj);
        
        addPixel(obj);
        removePixel(obj);
        invertPixel(obj, click);
        
        showPixels(obj);
        hidePixels(obj);
        showSolution(obj, Solutions);
        hideSolution(obj);
        show(obj);
        loadSolution(obj, solution);
        
        closeReqFcn(obj);
        
        controlHeight = fontSize2controlHeight(obj, fontSize);
        
    end
    
    methods(Hidden = true)
        function delete(obj)
            obj.MainFigure.delete;
            obj.AntennaBuilder.isGUIOpened = 0;
        end
    end
    
    methods(Static)
        scaleAxes(axes, mesh);
        [h1, h2, h3] = arrow(x, y, z, u, v, w, parent, headSize, ...
            toCentre, aScale);
        s = numberFormat(x, P);
    end
end

