function initialize(obj)
%% initialize gui inicialization
%
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com
%  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com

%% mainFigure
obj.MainFigure = figure('Visible', 'on');
obj.MainFigure.NumberTitle = 'off';
obj.MainFigure.Color = obj.FigureBackgroundColor;
figstate.maxfig(obj.MainFigure, 1); % maximizes figure
obj.MainFigure.Name = 'AntennaBuilder';
obj.MainFigure.MenuBar = 'none';
obj.MainFigure.Tag = 'AntennaBuilder';
obj.MainFigure.HandleVisibility = 'off';
obj.Handles.figure = obj.MainFigure;
drawnow;
%obj.MainFigure.Resize = 'off';

marginTop = 0.02;
marginLeft = 0.02;
panelWidth = 0.15;
textfieldWidth = (1- 3*marginLeft)/2;

panelHeights.control = 0.16;
panelHeights.results = 0.22;
panelHeights.users = 0.12;
panelHeights.history = 0.24;
panelHeights.total = panelHeights.control + panelHeights.results + ...
   panelHeights.users + panelHeights.history;
marginBottom = (1 - panelHeights.total - 3*marginTop) / 2;
panelHeightFromTop = 1;

%% mainAxes
obj.Handles.mainAxes = axes('Parent', obj.MainFigure);
obj.Handles.mainAxes.Visible = 'off';
obj.Handles.mainAxes.Position = [2 * marginLeft + panelWidth, ...
   marginTop, 1 - (3 * marginLeft + panelWidth), 1 - 2 * marginTop];
obj.Handles.mainAxes.DataAspectRatio = [1 1 1];

%% panel controls
panelHeightFromTop = panelHeightFromTop - marginBottom - panelHeights.control;
obj.Handles.panels.control = uipanel(...
   'Parent', obj.MainFigure,...
   obj.PanelCommonProperties{:}, ...
   'Units', 'normalized',...
   'Position', [marginLeft, panelHeightFromTop, panelWidth, panelHeights.control],...
   'Title', '');

%% plusButton
obj.Handles.buttons.plus = uicontrol( ...
   'Parent', obj.Handles.panels.control, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [0.05 0.77 0.9 0.2], ...
   'Visible', 'off',...
   'String', '+');

%% minusButton
obj.Handles.buttons.minus = uicontrol( ...
   'Parent', obj.Handles.panels.control, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [0.05 0.52 0.9 0.2], ...
   'Visible', 'off',...
   'String', '-');

%% clearButton
obj.Handles.buttons.clear = uicontrol( ...
   'Parent', obj.Handles.panels.control, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [0.05 0.52 0.9 0.44], ...
   'String', obj.ButtonClearString{1});

%% solveButton
obj.Handles.buttons.solve = uicontrol( ...
   'Parent', obj.Handles.panels.control, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [0.05 0.04 0.9 0.44], ...
   'String', obj.ButtonSolveString{1});

%% panel results
panelHeightFromTop = panelHeightFromTop - marginTop - panelHeights.results;
obj.Handles.panels.results = uipanel(...
   'Parent', obj.MainFigure,...
   obj.PanelCommonProperties{:}, ...
   'Units', 'normalized',...
   'Position', [marginLeft, panelHeightFromTop, panelWidth, panelHeights.results],...
   'Title', '');

heightFromTop = 1;
leftPosition = [0, 1] * (marginLeft+textfieldWidth) + marginLeft;
resultsPanelHeightPx = obj.Handles.panels.results.Position(4) * obj.MainFigure.Position(4);
textfieldHeight = obj.fontSize2controlHeight(obj.TextfieldFontSize) / resultsPanelHeightPx;
textfieldResultHeight = obj.fontSize2controlHeight(obj.TextfieldResultFontSize) / resultsPanelHeightPx;

%% text Current Qmax
heightFromTop = heightFromTop - marginTop - textfieldHeight;
obj.Handles.textfield.textCurrentCmax = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(1), heightFromTop, textfieldWidth, textfieldHeight],...
   'String', 'Current Q');

%% text my best Qmax
obj.Handles.textfield.textMyBestQmax = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(2), heightFromTop, textfieldWidth, textfieldHeight],...
   'String', 'User best');

%% results field current Qmax
heightFromTop = heightFromTop - textfieldResultHeight;
obj.Handles.textfield.resultCurrentQmax = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(1), heightFromTop, textfieldWidth, textfieldResultHeight],...
   'String', '-');

%% results field my best Qmax
obj.Handles.textfield.resultMyBestQmax = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(2), heightFromTop, textfieldWidth, textfieldResultHeight],...
   'String', '-');

%% waitbar axes
heightFromTop = heightFromTop - 2*marginTop - textfieldResultHeight;
nColorsPerSide = 7; % 100 slices of color per each side
nColors = 2*nColorsPerSide + 1; % number of colors in waitbar (should be odd)
xRange = linspace(-1, 1, nColors); % range from -1 to 1
CMap = flipud(results.colors.cbrewer.cbrewer('div', 'RdYlBu', nColors));
waitbarLeft = 2*marginLeft + 0.1;
waitbarWidth = 1-2*waitbarLeft;
obj.Handles.axes.waitbar = axes(...
   'Parent', obj.Handles.panels.results,...
   'Position', [waitbarLeft, heightFromTop, waitbarWidth, textfieldResultHeight]);
%% waitbar image
obj.Handles.waitbarImage = imagesc(obj.Handles.axes.waitbar, xRange);
colormap(obj.Handles.axes.waitbar, CMap);
% reset axes
set(obj.Handles.axes.waitbar,...
   'Box', 'on',...
   'YLim', [0 1] + 0.5,...
   'XLim', [0, nColors]+0.5,...
   'XTick', {},...
   'YTick', {},...
   'XColor', 'none',...
   'YColor', 'none',...
   'Color', obj.ResultFieldBackgroundColor);

%% waitbar line
obj.Handles.lines.waitbarLine = line(...
   obj.Handles.axes.waitbar,...
   [nColorsPerSide+1 nColorsPerSide+1], ...
   [0.1 0.9] + 0.5,...
   'Color', 'k',...%obj.Cmap(3, :),...
   'LineWidth', 3);

%% letter M
colorIdx = round(nColorsPerSide/4);
obj.Handles.textfield.laitbarLetterM = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [marginLeft, heightFromTop-marginTop, 0.1, textfieldResultHeight],...
   'ForegroundColor', CMap(colorIdx, :),...
   'BackgroundColor', obj.FigureBackgroundColor,...
   'String', 'M');

%% letter E
obj.Handles.textfield.laitbarLetterE = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [1-(marginLeft+0.1), heightFromTop-marginTop, 0.1, textfieldResultHeight],...
   'ForegroundColor', CMap(end-colorIdx, :),...
   'BackgroundColor', obj.FigureBackgroundColor,...
   'String', 'E');

%% text Qmax limit
heightFromTop = heightFromTop - 2*marginTop - textfieldHeight;
obj.Handles.textfield.textQmaxLimit = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(1), heightFromTop, textfieldWidth, textfieldHeight],...
   'String', 'Q limit');

%% text Qmax best
obj.Handles.textfield.textQmaxBest = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [leftPosition(2), heightFromTop, textfieldWidth, textfieldHeight],...
   'String', 'Session best');

%% results field Qmax limit
heightFromTop = heightFromTop - textfieldResultHeight;
obj.Handles.textfield.resultQmaxLimit = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'ForegroundColor', obj.LimitColor,...
   'Units', 'normalized',...
   'Position', [leftPosition(1), heightFromTop, textfieldWidth, textfieldResultHeight],...
   'String', obj.numberFormat(obj.AntennaBuilder.Qlim));

%% results field Qmax best
obj.Handles.textfield.resultQmaxBest = uicontrol(...
   'Parent', obj.Handles.panels.results,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'ForegroundColor', obj.RecordColor,...
   'Position', [leftPosition(2), heightFromTop, textfieldWidth, textfieldResultHeight],...
   'String', '-');

%% panel User
panelHeightFromTop = panelHeightFromTop - marginTop - panelHeights.users;
obj.Handles.panels.user = uipanel(...
   'Parent', obj.MainFigure,...
   obj.PanelCommonProperties{:}, ...
   'Units', 'normalized',...
   'Position', [marginLeft, panelHeightFromTop, panelWidth, panelHeights.users],...
   'Title', '');

%% new user button
obj.Handles.buttons.newUser = uicontrol( ...
   'Parent', obj.Handles.panels.user, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [0.05 0.04 0.9 0.44], ...
   'String', 'New user');

%% user name
obj.Handles.textfield.textUserName = uicontrol(...
   'Parent', obj.Handles.panels.user,...
   obj.TextResultCommonProperties{:},...
   'Units', 'normalized',...
   'Position', [0.05 0.50 0.9 0.44],...
   'String', obj.AntennaBuilder.User.name);

%% history axes
panelHeightFromTop = panelHeightFromTop - marginTop - panelHeights.history;
obj.Handles.axes.history = axes(...
   'Parent', obj.MainFigure,...
   'Units', 'normalized',...
   'Position', [marginLeft, panelHeightFromTop, panelWidth, panelHeights.history]);

%% history bar
nBars = obj.AntennaBuilder.HistoryNBars;
nColors = size(obj.HistoryBarCmap, 1);
obj.Handles.historyBar = bar(obj.Handles.axes.history, [0 1], ...
   zeros(2, nColors), 'stacked');

%% update axes
yLim = feval(obj.AntennaBuilder.HistoryYLim, obj.AntennaBuilder.Qlim, Inf);
set(obj.Handles.axes.history,...
   'XLim', [0.5, nBars+0.5],...
   'YLim', yLim,...
   'XTick', 0:obj.AntennaBuilder.HistoryXTicksSpacing:nBars,...
   'YScale', obj.AntennaBuilder.HistoryYScale,...
   'XMinorTick', 'on',...
   'Color', obj.FigureBackgroundColor,...
   'XColor', obj.MainFontColor,...
   'YColor', obj.MainFontColor,...
   'Box', 'off');
colormap(obj.Handles.axes.history, obj.HistoryBarCmap);

%% history limit line
QlimValue = feval(obj.AntennaBuilder.HistoryYFcn, obj.AntennaBuilder.Qlim);
obj.Handles.lines.historyLimit = line(obj.Handles.axes.history, ...
   [-1, nBars+1], [QlimValue, QlimValue], ...
   'Color', obj.LimitColor, obj.HistoryLineCommonProperties{:});

%% history record line
obj.Handles.lines.historyRecord = line(obj.Handles.axes.history, ...
   [-1, nBars+1], [NaN, NaN], ...
   'Color', obj.RecordColor, obj.HistoryLineCommonProperties{:});

%% axes advertisment
obj.Handles.axes.advertisement = axes(obj.MainFigure,...
'Units', 'normalized',...   
'Color', obj.FigureBackgroundColor,...
'XColor', obj.FigureBackgroundColor,...
'YColor', obj.FigureBackgroundColor,...
'Position', [1-marginLeft marginTop 0 0]);

%% text advertisment
obj.Handles.textAdvertisment = text(obj.Handles.axes.advertisement, ...
   0, 0, 'Powered by AToM & FOPS. CEM Group, 2018.',...
   'Color', obj.MainFontColor,...
   'FontSize', obj.TextfieldFontSize,...
   'HorizontalAlignment', 'right');

%% set callbacks
obj.setCallbacks
end

