function newUser(obj)
%% newUser open figure for new user definiton
%
% Included in AToM, info@antennatoolbox.com
%  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com

if ~isempty(obj.NewUserFigure)
   obj.NewUserFigure.delete();
end

dispSize = get(0, 'ScreenSize');
figSize = [400 240];
figPosition = [(dispSize(3)-figSize(1))/2 ...
   (dispSize(4)-figSize(2))/2 ...
   figSize(1)  figSize(2)];


obj.NewUserFigure = figure('Position', figPosition,...
   'NumberTitle', 'off',...
   'Name', 'AntennaBuilder: New User',...
   'MenuBar', 'none',...
   'Tag', 'AntennaBuilderNewUser',...
   'HandleVisibility', 'off',...
   ...'WindowStyle', 'modal',...
   'Color', obj.FigureBackgroundColor,...
   'Resize', 'off');

marginLeft = 0.05;
marginTop = 0.03;
buttonWidth = 1 - 2 * marginLeft;
heightFromBottom = marginTop;
randColor = fix(rand(1, 3) * 1000) ./ 1000;
colorFormat = @(c) sprintf('[%1.2f %1.2f %1.2f]', c);

textfieldHeight = obj.fontSize2controlHeight(obj.TextfieldFontSize) / figSize(2);
textfieldResultHeight = obj.fontSize2controlHeight(obj.TextfieldResultFontSize) / figSize(2);
buttonHeight = obj.fontSize2controlHeight(obj.ButtonFontSize) / figSize(2);

%% create button
handles.createButton = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [marginLeft heightFromBottom buttonWidth buttonHeight], ...
   'String', 'Create new user');
heightFromBottom = heightFromBottom + 3*marginTop + buttonHeight;

%% email edit
handles.emailEdit = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.ButtonCommonProperties{:}, ...
   'Style', 'edit',...
   'Units', 'normalized', ...
   'Position', [marginLeft heightFromBottom buttonWidth textfieldResultHeight], ...
   'String', '');
heightFromBottom = heightFromBottom + marginTop + textfieldResultHeight;

%% email text
handles.emailText = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.TextCommonProperties{:}, ...
   'Style', 'text',...
   'Units', 'normalized', ...
   'Position', [marginLeft heightFromBottom buttonWidth textfieldHeight], ...
   'String', 'E-mail:');
heightFromBottom = heightFromBottom + 3*marginTop + textfieldHeight;

%% name edit
handles.nameEdit = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.ButtonCommonProperties{:}, ...
   'Style', 'edit',...
   'Units', 'normalized', ...
   'Position', [marginLeft heightFromBottom 0.8*buttonWidth buttonHeight], ...
   'String', obj.AntennaBuilder.randomName());

%% name button
handles.nameButton = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.ButtonCommonProperties{:}, ...
   'Units', 'normalized', ...
   'Position', [2*marginLeft+0.8*buttonWidth heightFromBottom 0.2*buttonWidth-marginLeft buttonHeight], ...
   'String', '',...
   'CData', refreshIcon());
heightFromBottom = heightFromBottom + marginTop + textfieldResultHeight;

%% name text
handles.nameText = uicontrol( ...
   'Parent', obj.NewUserFigure, ...
   obj.TextCommonProperties{:}, ...
   'Style', 'text',...
   'Units', 'normalized', ...
   'Position', [marginLeft heightFromBottom buttonWidth textfieldHeight], ...
   'String', 'Name:');
heightFromBottom = heightFromBottom + marginTop + textfieldHeight;

%% set callbacks
handles.createButton.Callback = @(a, b) createNewUser();
handles.colorButton.Callback = @(a, b) selectColor();
handles.nameButton.Callback = @(a, b) generateNewName();

   function createNewUser
      obj.AntennaBuilder.User.name = handles.nameEdit.String;
      obj.AntennaBuilder.User.email = handles.emailEdit.String;
      %       obj.AntennaBuilder.User.color = str2num(handles.colorResult.String);
      obj.NewUserFigure.delete;
      obj.reset;
      obj.updateUser;
   end

   function selectColor()
      c = uisetcolor(randColor);
      handles.colorResult.String = colorFormat(c);
      handles.colorResult.ForegroundColor = c;
   end

   function generateNewName()
      handles.nameEdit.String = obj.AntennaBuilder.randomName;
   end

   function C = refreshIcon()      
      A = [0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	8.0	148.0	103.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	55.0	255.0	255.0	112.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	69.0	236.0	255.0	122.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	37.0	91.0	131.0	139.0	215.0	255.0	255.0	133.0	6.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	86.0	190.0	252.0	255.0	255.0	255.0	255.0	255.0	255.0	255.0	67.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	43.0	191.0	255.0	255.0	255.0	228.0	188.0	153.0	212.0	255.0	255.0	131.0	2.0	0.0	3.0	35.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	78.0	242.0	255.0	255.0	172.0	70.0	10.0	0.0	42.0	227.0	255.0	140.0	0.0	0.0	10.0	166.0	245.0	81.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	77.0	255.0	255.0	222.0	70.0	0.0	0.0	0.0	27.0	250.0	255.0	150.0	0.0	0.0	0.0	30.0	230.0	255.0	255.0	78.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	38.0	244.0	255.0	205.0	23.0	0.0	0.0	0.0	0.0	6.0	141.0	167.0	0.0	0.0	0.0	0.0	0.0	23.0	204.0	255.0	245.0	38.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	194.0	255.0	226.0	21.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	20.0	225.0	255.0	195.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	78.0	255.0	255.0	67.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	66.0	255.0	255.0	79.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	189.0	255.0	181.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	179.0	255.0	191.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	28.0	249.0	255.0	72.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	70.0	255.0	251.0	30.0	0.0	0.0	0.0
         0.0	0.0	0.0	83.0	255.0	236.0	11.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	9.0	234.0	255.0	86.0	0.0	0.0	0.0
         0.0	0.0	0.0	125.0	255.0	195.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	193.0	255.0	128.0	0.0	0.0	0.0
         0.0	0.0	0.0	146.0	255.0	172.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	169.0	255.0	148.0	0.0	0.0	0.0
         0.0	0.0	0.0	146.0	255.0	171.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	169.0	255.0	148.0	0.0	0.0	0.0
         0.0	0.0	0.0	126.0	255.0	194.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	193.0	255.0	128.0	0.0	0.0	0.0
         0.0	0.0	0.0	85.0	255.0	235.0	10.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	10.0	234.0	255.0	86.0	0.0	0.0	0.0
         0.0	0.0	0.0	29.0	250.0	255.0	71.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	69.0	255.0	250.0	30.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	190.0	255.0	180.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	178.0	255.0	192.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	78.0	255.0	255.0	67.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	64.0	255.0	255.0	81.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	194.0	255.0	225.0	21.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	19.0	224.0	255.0	197.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	37.0	245.0	255.0	204.0	22.0	0.0	0.0	0.0	0.0	0.0	164.0	141.0	7.0	0.0	0.0	0.0	0.0	21.0	202.0	255.0	246.0	40.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	78.0	255.0	255.0	230.0	31.0	0.0	0.0	0.0	147.0	255.0	252.0	28.0	0.0	0.0	0.0	67.0	220.0	255.0	255.0	80.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	81.0	245.0	170.0	10.0	0.0	0.0	137.0	255.0	229.0	44.0	0.0	9.0	67.0	169.0	255.0	255.0	243.0	81.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	37.0	4.0	0.0	2.0	128.0	255.0	255.0	212.0	151.0	186.0	226.0	255.0	255.0	255.0	193.0	45.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	65.0	255.0	255.0	255.0	255.0	255.0	255.0	255.0	253.0	193.0	89.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	7.0	133.0	255.0	255.0	216.0	141.0	133.0	93.0	39.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	122.0	255.0	236.0	70.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	112.0	255.0	255.0	57.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	103.0	151.0	8.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0	0.0
         ];
      
      A(A==0) = NaN;
%       A(A>0) = 255;
      C = repmat(A/255, 1, 1, 3);
   end
end