function showSolution(obj)
%% showSolution shows solution
%
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com

solution = obj.AntennaBuilder.Solutions{end};
obj.hideSolution;

%% compute current
handles.fig = obj.MainFigure;
handles.axes = obj.Handles.mainAxes;
optionsCurrent = struct( ...
    'showCurrentIntensity', true, ...
    'showCurrentArrows', true, ...
    'showColorBar', false);
optionsCharge.showCharge = true;

%% mesh modifcator
mesh = obj.AntennaBuilder.Mesh;
basisFcns = obj.AntennaBuilder.BasisFcns;
tempData = unique(reshape(basisFcns.data(solution.iVec~=0, [2 4]), [], 1));
mesh.connectivityList = mesh.connectivityList(tempData, :);

mesh.triangleCentroids = mesh.triangleCentroids(tempData, :);
mesh.triangleEdgeLengths = mesh.triangleEdgeLengths(tempData, :);

if strcmpi(obj.ButtonClearState, 'current') && ~isempty(tempData)
    [J(:, 1), J(:, 2), J(:, 3)] = results.calculateCurrent(...
        obj.AntennaBuilder.Mesh, basisFcns, solution.iVec);
    J = J(tempData, :);
    
    handles = results.plotCurrent(mesh, 'J', J, 'handles', handles, ...
        'options', optionsCurrent, 'part', 'abs', ...
        'arrowLength', 0.4 * min(mesh.triangleEdgeLengths), ...
        'arrowScale', 'proportional');
    
    obj.Handles.solution.triangles = handles.triangles;
    obj.Handles.solution.arrow = handles.arrow;
elseif strcmpi(obj.ButtonClearState, 'charge') && ~isempty(tempData)
    divJ = results.calculateCharge(...
        obj.AntennaBuilder.Mesh, basisFcns, solution.iVec);
    divJ = divJ(tempData, :);
    handles = results.plotCharge(mesh, 'divJ', divJ, ...
        'handles', handles, 'options', optionsCharge);
    
    obj.Handles.solution.triangles = handles.triangles;
end

obj.Handles.mainAxes.CLimMode = 'auto';
obj.scaleAxes(obj.Handles.mainAxes, obj.AntennaBuilder.Mesh);
drawnow;

end

