function update(obj)
%% update updates scene appearance
%
% Included in AToM, info@antennatoolbox.com
%  2018, Vit Losenicky, CTU in Prague, vit.losenicky@antennatoolbox.com
%  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com

map = obj.AntennaBuilder.Map;
nPixels = length(map);

colors = obj.AntennaBuilder.PixelValues + 2;
colors(obj.AntennaBuilder.FedPixels) = 1;

%% PIXELS =================================================================
if ~isfield(obj.Handles, 'polygons') || ...
        isempty(obj.Handles.polygons) || ...
        length(obj.Handles.polygons) ~= nPixels || ...
        any(~obj.Handles.polygons.isvalid)
    
    obj.Handles.polygons = gobjects(nPixels, 1);
    for thisPixel = 1:nPixels
        obj.Handles.polygons(thisPixel) = patch( ...
            'parent', obj.Handles.mainAxes, ...
            'XData', map{thisPixel}.pPixel(:,1), ...
            'YData', map{thisPixel}.pPixel(:,2), ...
            'FaceColor', obj.Cmap(colors(thisPixel), :), ...
            'Visible', 'on');
    end
else
    for thisPixel = 1:nPixels
        obj.Handles.polygons(thisPixel).FaceColor = ...
            obj.Cmap(colors(thisPixel), :);
        obj.Handles.polygons(thisPixel).Visible = 'on';
    end
end

%% FEEDING ================================================================
if (~isfield(obj.Handles, 'fedEdge') || ...
        isempty(obj.Handles.fedEdge) || ...
        any(~obj.Handles.fedEdge.isvalid) || ...
        length(obj.Handles.fedEdge) ~= size(obj.FeedingPosition, 1)) && ...
        ~isempty(obj.FeedingPosition)
    
    if isfield(obj.Handles, 'fedEdge')
        delete(obj.Handles.fedEdge);
    end
    
    obj.Handles.fedEdge = line( ...
        [obj.FeedingPosition(:, 1) obj.FeedingPosition(:, 4)]', ...
        [obj.FeedingPosition(:, 2) obj.FeedingPosition(:, 5)]', ...
        'Parent', obj.Handles.mainAxes);
    set(obj.Handles.fedEdge(:), 'Color', obj.FeederColor);
    set(obj.Handles.fedEdge(:), 'LineWidth', obj.FeederWidth);
    set(obj.Handles.fedEdge(:), 'Visible', 'on');
elseif ~isempty(obj.FeedingPosition)
    for thisFeeder = 1:size(obj.FeedingPosition, 1)
        obj.Handles.fedEdge(thisFeeder).XData = ...
            [obj.FeedingPosition(thisFeeder, 1) ...
            obj.FeedingPosition(thisFeeder, 4)];
        obj.Handles.fedEdge(thisFeeder).YData = ...
            [obj.FeedingPosition(thisFeeder, 2) ...
            obj.FeedingPosition(thisFeeder, 5)];
    end
elseif isfield(obj.Handles, 'fedEdge') && isempty(obj.FeedingPosition)
    delete(obj.Handles.fedEdge);
end

% ARROWS
if (~isfield(obj.Handles, 'feederArrow') || ...
        isempty(obj.Handles.feederArrow) || ...
        any(any(~obj.Handles.feederArrow.isvalid)) || ...
        size(obj.Handles.feederArrow, 1) ~= ...
        size(obj.FeedingPosition, 1)) && ...
        ~isempty(obj.FeedingPosition)
    
    if isfield(obj.Handles, 'feederArrow')
        delete(obj.Handles.feederArrow);
        obj.Handles.feederArrow = gobjects(0);
    end
    
    for thisFeeder = 1:size(obj.FeedingPosition, 1)
        temp = obj.AntennaBuilder.FeedingArrows(thisFeeder, :);
        temp(1, 4:6) = temp(1, 7) * temp(1, 4:6);
        
        [hndl(1, 1), hndl(2, 1), hndl(3, 1)] = ...
            obj.arrow(temp(1), temp(2), temp(3), ...
            temp(4), temp(5), temp(6), obj.Handles.mainAxes, ...
            15 / temp(1, 7), 1, 1);
        obj.Handles.feederArrow(thisFeeder, :) = hndl;
    end
    set(obj.Handles.feederArrow(:), 'EdgeColor', obj.FeederColor);
    set(obj.Handles.feederArrow(:), 'FaceColor', obj.FeederColor);
    set(obj.Handles.feederArrow(:, 1:2), 'FaceAlpha', 1);
    set(obj.Handles.feederArrow(:, 3), 'LineWidth', 1);
    
elseif isfield(obj.Handles, 'feederArrow') && isempty(obj.FeedingPosition)
    delete(obj.Handles.feederArrow);
end

%% PIXEL ID NUMBERS =======================================================
if obj.AntennaBuilder.DisplayIDs && ...
        (~isfield(obj.Handles, 'pixelNumbers') || ...
        isempty(obj.Handles.pixelNumbers))
    obj.Handles.pixelNumbers = gobjects(nPixels, 1);
    for thisPixel = 1:nPixels
        textPosition = sum(map{thisPixel}.pPixel(:,1:2), 1) / ...
            size(map{thisPixel}.pPixel, 1);
        obj.Handles.pixelNumbers(thisPixel) = ...
            text(textPosition(1), textPosition(2), num2str(thisPixel), ...
            'Parent', obj.Handles.mainAxes, ...
            'FontSize', obj.TextFontSize, ...
            'Color', obj.TextFontColor, ...
            'FontName', obj.MainFont, ...
            'HorizontalAlignment', 'center', ...
            'VerticalAlignment', 'middle');
    end
elseif ~obj.AntennaBuilder.DisplayIDs && ...
        (isfield(obj.Handles, 'pixelNumbers') && ...
        ~isempty(obj.Handles.pixelNumbers))
    delete(obj.Handles.pixelNumbers);
end

%% AXES SCALING ===========================================================
obj.scaleAxes(obj.Handles.mainAxes, obj.AntennaBuilder.Mesh);

%% HISTORY CHART ==========================================================
obj.updateResults;

drawnow;
end

