function updateResults(obj)
%% updateResults update results in results panel
%
% Included in AToM, info@antennatoolbox.com
%  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com

Solutions = obj.AntennaBuilder.Solutions;

if isempty(Solutions)
   allQmax = Inf;
   totalBest = Inf;
   Qratio = 0;
   allNames = [];
else
   % vector of all Q max in Solutions
   allQmax = cellfun(@(c) c.Qmax, Solutions);
   % logical vector which results are mine
   allNames = cellfun(@(c) c.user.name, Solutions, 'UniformOutput', false);
   myResults = strcmp(allNames, Solutions{end}.user.name);
   
   currentQmax = Solutions{end}.Qmax;
   totalBest = min(allQmax);
   myBest = min(allQmax(myResults));
   Qratio = 2*(Solutions{end}.Qe - Solutions{end}.Qm)/currentQmax;

   %% update textFields
   % current Qmax
   obj.Handles.textfield.resultCurrentQmax.String = ...
      obj.numberFormat(currentQmax);
   % my best Qmax
   obj.Handles.textfield.resultMyBestQmax.String = ...
      obj.numberFormat(myBest);
   % total best
   obj.Handles.textfield.resultQmaxBest.String = ...
      obj.numberFormat(totalBest);
end

%% QE / QM waitbar
xBar = (Qratio+1) * (obj.Handles.waitbarImage.XData(2)-1)/2;
obj.Handles.lines.waitbarLine.XData = [xBar xBar] + 1;


%% history
[~, ~, ic] = unique(allNames, 'stable'); % find changes in names
nColors = size(obj.HistoryBarCmap, 1); % number of oclors in bar
nQ = length(allQmax); % number of computed results
icMod = mod(ic, nColors) + 1; % color index numbers
historyDataX = 1:nQ;
for iColor = 1:nColors
   thisColorIdx = icMod == iColor;
   obj.Handles.historyBar(iColor).XData = historyDataX;
   obj.Handles.historyBar(iColor).YData = allQmax .* thisColorIdx';
end

%% xLim
nBars = obj.AntennaBuilder.HistoryNBars;
if nBars > nQ
   xLim = [0, nBars];
else
   xLim = [nQ-nBars, nQ];
end

%% yLim
if nBars > nQ || any(isinf(allQmax))
   lastResults = allQmax;
else
   lastResults = allQmax(end-nBars+1:end);
end
yLim = feval(obj.AntennaBuilder.HistoryYLim, obj.AntennaBuilder.Qlim, ...
   lastResults);

%% update axes
obj.Handles.axes.history.XLim = xLim+0.5;
obj.Handles.axes.history.XTick = ...
   xLim(1):obj.AntennaBuilder.HistoryXTicksSpacing:xLim(2);
obj.Handles.axes.history.YScale = obj.AntennaBuilder.HistoryYScale;
obj.Handles.axes.history.YLim = yLim;

%% update lines
QbestValue = feval(obj.AntennaBuilder.HistoryYFcn, totalBest);
QbestValue = min(QbestValue, yLim(2));
obj.Handles.lines.historyRecord.XData = xLim + [-1 1];
obj.Handles.lines.historyRecord.YData = [QbestValue QbestValue];

obj.Handles.lines.historyLimit.XData = xLim + [-1 1];
end



