%% load all files from history folder
folderPath = 'history';
files = dir(fullfile(folderPath,'*.mat'));
nFiles = length(files);
allSolutions = [];
for iFile = 1:nFiles
   thisFile = fullfile(folderPath, files(iFile).name);
   loadedData = load(thisFile);
   allSolutions = [allSolutions, loadedData.solutions];
end

%% all Names
allNames  = cellfun(@(c) c.user.name, allSolutions, 'UniformOutput', false);
allEmails = cellfun(@(c) c.user.email, allSolutions, 'UniformOutput', false);
allQMax   = cellfun(@(c) c.Qmax, allSolutions);

%% bestResults
uniqNames = unique(allNames);
nNames = length(uniqNames);
bestResults = cell(nNames, 5);
for iName = 1:nNames
   thisName = uniqNames(iName);
   thisResults = strcmp(allNames, thisName);
   thisEmail = allEmails(thisResults);
   thisEmail = thisEmail(1);
   [bestQ, iQ] = min(allQMax(thisResults));
   %position in allSolutions
   iPos = find(thisResults, iQ);
   iPos = iPos(end);
   
   bestResults{iName, 1} = thisName{1};
   bestResults{iName, 2} = thisEmail{1};
   bestResults{iName, 3} = bestQ;
   bestResults{iName, 4} = sum(thisResults);
   bestResults{iName, 5} = allSolutions{iPos};
end

%% SORT
bestResults = sortrows(bestResults, 3);

%% plot Table
tableFig = figure;
ut = uitable(tableFig, 'Data', bestResults(:, 1:4),...
'Units', 'normalized',...
'Position', [0.05 0.05 0.9 0.9],...
'ColumnName', {'Name', 'E-mail', 'Best Q', 'Attempts'});

%% load task
load('data\rectangle_2over1_ka_0p62_EMiT_Shape.mat')
load('data\rectangle_2over1_ka_0p62_EMiT_Operators.mat')

%% create Antenna builder
AB = AntennaBuilder();
AB.setTask(Map, Mesh, BF, ka, OP);
AB.addFeeder(fedPixels, 1, 0);
AB.Control = 'm';
AB.HistoryYLim = @(Qlim, lastResults) [21, 31];
AB.HistoryYScale = 'lin';
% AB.HistoryNBars = 25;

resultID = 1;
% set user name
AB.setUser(bestResults{resultID, 1}, '', [0.8 0.8 0.8]);
% load best solution
AB.loadSolution(bestResults{resultID, 5});
% solve
AB.solve;